This project is a collection of utility modules with helpful python functionality not available in the standard library. As it's currently in early development, the modules are not yet stable and may change in the future. Use in your code at your own risk.